@@ -1,4 +1,5 @@
-# Copyright 2017-2019 CERN for the benefit of the ATLAS collaboration.
+# -*- coding: utf-8 -*-
+# Copyright 2017-2021 CERN
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,17 +14,18 @@
 # limitations under the License.
 #
 # Authors:
-# - Vincent Garonne <vgaronne@gmail.com>, 2017
-# - Eric Vaandering <ericvaandering@gmail.com>, 2018
+# - Vincent Garonne <vincent.garonne@cern.ch>, 2017
+# - Eric Vaandering <ewv@fnal.gov>, 2018-2021
 # - sartiran <root@polgrid107.in2p3.fr>, 2018
-# - Hannes Hansen <hannes.jakob.hansen@cern.ch>, 2018
+# - Hannes Hansen <hannes.jakob.hansen@cern.ch>, 2018-2019
 # - Sartirana Andrea <sartiran@llr.in2p3.fr>, 2018
-# - Martin Barisits <martin.barisits@cern.ch>, 2019
-# - Mario Lassnig <mario.lassnig@cern.ch>, 2019
+# - Martin Barisits <martin.barisits@cern.ch>, 2019-2021
+# - Mario Lassnig <mario.lassnig@cern.ch>, 2019-2021
+# - Jaroslav Guenther <jaroslav.guenther@cern.ch>, 2020
 # - Andrew Lister <andrew.lister@stfc.ac.uk>, 2019
 # - Eli Chadwick <eli.chadwick@stfc.ac.uk>, 2020
-#
-# PY3K COMPATIBLE
+# - Benedikt Ziemons <benedikt.ziemons@cern.ch>, 2020
+# - Radu Carpa <radu.carpa@cern.ch>, 2021
 
 from jsonschema import validate, ValidationError
 
@@ -54,7 +56,7 @@ ACTIVITY = {"description": "Activity name",
                      "Production Input", "Production Output",
                      "Analysis Input", "Analysis Output", "Staging",
                      "T0 Export", "T0 Tape", "Upload/Download (Job)",
-                     "Upload/Download (User)", "User Subscriptions"]}
+                     "Upload/Download (User)", "User Subscriptions", "Data Challenge"]}
 
 SCOPE_LENGTH = 25
 
